@@ -3,7 +3,7 @@ package Mixin::Event::Dispatch;
 use strict;
 use warnings;
 
-our $VERSION = '1.006';
+our $VERSION = '2.000';
 
 # Key name to use for event handlers. Nothing should be
 # accessing this directly so we don't mind something
@@ -22,7 +22,7 @@ Mixin::Event::Dispatch - mixin methods for simple event/message dispatch framewo
 
 =head1 VERSION
 
-Version 1.006
+version 2.000
 
 =head1 SYNOPSIS
 
@@ -43,10 +43,6 @@ Version 1.006
  # should get output 'Event data: like this'
  $obj->unsubscribe_from_event(another_event => $code);
 
- $obj->trace_events_for(sub {
-   $obj->invoke_event(another_event => 'like this');
- });
-
  # Note that handlers will be called for each instance of an event until they return false,
  # at which point the handler will be removed, so for a permanent handler, make sure to return 1.
  $obj->add_handler_for_event(some_event => sub { my $self = shift; warn "had some_event: @_"; 1; });
@@ -103,10 +99,11 @@ Returns $self if a handler was found, undef if not.
 sub invoke_event {
 	my ($self, $event_name, @param) = @_;
 	my $handlers = $self->event_handlers->{$event_name} || [];
+	
 	unless(@$handlers) {
 		# Legacy flag - when set, pass control to on_$event_name
 		# if we don't have a handler defined.
-		if($self->EVENT_DISPATCH_ON_FALLBACK && (my $code = $self->can("on_$event_name"))) {
+		if($self->can('EVENT_DISPATCH_ON_FALLBACK') && $self->EVENT_DISPATCH_ON_FALLBACK && (my $code = $self->can("on_$event_name"))) {
 			local $@;
 			eval {
 				$code->($self, @_);
@@ -307,6 +304,8 @@ __END__
 
 =head1 API HISTORY
 
+Version 2.000 (will) implement the L<Mixin::Event::Dispatch::Methods> class.
+
 Version 1.000 implemented L</subscribe_to_event> and L<Mixin::Event::Dispatch::Event>.
 
 Version 0.002 changed to use L</event_handlers> instead of C< event_stack > for storing the available handlers (normally only L<invoke_event> and
@@ -314,12 +313,14 @@ L<add_handler_for_event> are expected to be called directly).
 
 =head1 ROLE vs. MIXIN
 
-Most role systems should be able to use this class - either directly, or through a thin wrapper which adds
-any required boilerplate. Try L<Moose> or L<Role::Tiny> / L<Moo::Role> for that.
+Role systems might work using the L<Mixin::Event::Dispatch::Methods> module, which allows
+import of the relevant methods. Try combing this with a thin wrapper using L<Role::Tiny> / L<Moo::Role> /
+L<Moose> for that. The C<t/moo-role.t> and C<t/role-tiny.t> tests may provide some
+inspiration.
 
-Alternatively, you could use this as a component via L<Class::C3::Componentised>.
+Alternatively, you could perhaps use this as a component via L<Class::C3::Componentised>.
 
-(I haven't tried any of the above options myself, please let me know if I'm spreading
+(I haven't really used any of the above options myself, please let me know if I'm spreading
 disinformation here)
 
 =head1 SEE ALSO
@@ -342,9 +343,11 @@ L<Event-Reflexive programming|http://leonerds-code.blogspot.co.uk/search/label/e
 
 =item * L<MooseX::Event> - node.js-inspired events, for Moose users
 
+=item * L<Beam::Emitter> - a L<Moo::Role> for event handling
+
 =back
 
-Note that some frameworks such as L<Reflex> and L<POE> already have comprehensive message-passing
+Note that some frameworks such as L<Reflex>, L<POE> and L<Mojolicious> already have comprehensive message-passing
 and callback interfaces.
 
 If you're looking for usage examples, try the following:
@@ -374,7 +377,10 @@ Tom Molesworth <cpan@perlsite.co.uk>
 with thanks to various helpful people on freenode #perl who suggested making L</event_handlers> into an
 accessor (to support non-hashref objects) and who patiently tried to explain about roles.
 
+L<Mixin::Event::Dispatch::Methods> suggested by mst, primarily for better integration with object
+systems such as Moo(se).
+
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2014, based on code originally part of L<EntityModel>.
+Copyright Tom Molesworth 2011-2015, based on code originally part of L<EntityModel>.
 Licensed under the same terms as Perl itself.
